[![PyPI version](https://badge.fury.io/py/spatial-sites.svg)](https://badge.fury.io/py/spatial-sites)

# [WIP] spatial-sites
A simple Python package for representing and manipulating sets of N-dimensional spatial coordinates.

This is a work-in-progress.

## Installation

`pip install spatial-sites`

## Examples

```python
from spatial_sites import Sites

atoms = Sites(...)
```
